==> 1.0.0.zip: terraform-provider-dynamix/samples/cloudapi/bservice/data_bservice_list/main.tf <==
/*
Пример использования
Получение списка доступных базовых сервисов
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_bservice_list" "bsl" {
  #фильтр по id базового сервиса
  #опциональный параметр
  #тип - целое число
  #by_id = 100

  #фильтр по имени базового сервиса
  #опциональный параметр
  #тип - строка
  #name = "test"

  #id аккаунта для фильтрации данных
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #account_id = 11111

  #фильтр по имени ресурсной группы
  #опциональный параметр
  #тип - строка
  #rg_name = "test"

  #id ресурсной группы, используется для фильтрации
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #rg_id = 11111

  #фильтр по техническому статусу
  #опциональный параметр
  #тип - строка
  #tech_status = "STARTED"

  #фильтр по статусу
  #опциональный параметр
  #тип - строка
  #status = "ENABLED"

  #фильтр по имени аккаунта
  #опциональный параметр
  #тип - строка
  #account_name = "test"

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #номер страницы для отображения
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #page = 2

  #размер страницы
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #size = 3
}

output "test" {
  value = data.dynamix_bservice_list.bsl
}

==> 1.2.1.zip: terraform-provider-dynamix/samples/cloudapi/bservice/data_bservice_list/main.tf <==
/*
Пример использования
Получение списка доступных базовых сервисов
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DYNAMIX_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DYNAMIX_OAUTH2_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_bservice_list" "bsl" {
  #фильтр по id базового сервиса
  #опциональный параметр
  #тип - целое число
  #by_id = 100

  #фильтр по имени базового сервиса
  #опциональный параметр
  #тип - строка
  #name = "test"

  #id аккаунта для фильтрации данных
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #account_id = 11111

  #фильтр по имени ресурсной группы
  #опциональный параметр
  #тип - строка
  #rg_name = "test"

  #id ресурсной группы, используется для фильтрации
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #rg_id = 11111

  #фильтр по техническому статусу
  #опциональный параметр
  #тип - строка
  #tech_status = "STARTED"

  #фильтр по статусу
  #опциональный параметр
  #тип - строка
  #status = "ENABLED"

  #фильтр по имени аккаунта
  #опциональный параметр
  #тип - строка
  #account_name = "test"

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #номер страницы для отображения
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #page = 2

  #размер страницы
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #size = 3
}

output "test" {
  value = data.dynamix_bservice_list.bsl
}
